@@ -101,7 +101,7 @@ void Player::on_backwardButton_clicked()
 
 void Player::on_forwardButton_clicked()
 {
-    if (this->ui->playListWidget->currentRow() < this->ui->playListWidget->count() && ui->playListWidget->count() != 0)
+    if (ui->playListWidget->count() > 1 && this->ui->playListWidget->currentRow() < this->ui->playListWidget->count() && ui->playListWidget->count() != 0)
     {
         reload = true;
         this->ui->playListWidget->item(this->ui->playListWidget->currentRow())->setSelected(false);
