@@ -4,6 +4,7 @@
 #include <QWidget>
 #include <QTreeWidgetItem>
 #include <playlists.h>
+#include <QDialogButtonBox>
 
 namespace Ui {
     class Playlist;
@@ -22,7 +23,8 @@ public:
 
 private slots:
     void on_treeWidget_itemClicked(QTreeWidgetItem *item, int column);
-    void on_treeWidget_itemDoubleClicked(QTreeWidgetItem *item, int column);
+    void deleteArticle();
+    void openArticle();
 
 signals:
     void articleSelected(QTreeWidgetItem *item, int column);
@@ -34,6 +36,9 @@ private:
     QMap<QString, QString> *titles;
     Playlists *playlistlist;
     void updateList();
+    QDialogButtonBox *box;
+    QTreeWidgetItem *clickedItem;
+    int clickedColumn;
 
 };
 
